CSE API Documentation

companyInfoSummery

URL: `https://www.cse.lk/api/companyInfoSummery`

Parameters: `symbol` (string, required)

Example Response:

    {
      "reqLogo": {"path": "upload_logo/378_1601611239.jpeg"},
      "reqSymbolInfo": {"symbol": "LOLC.N0000", "name": "L O L C HOLDINGS PLC", ...}
    }

Logo:

tradeSummary

    {"reqTradeSummery": [{"symbol": "ABAN.N0000", "price": 579.75, ...}]

todaySharePrice

    [{"symbol": "ABAN.N0000", "lastTradedPrice": 579.75, ...}]

topGainers

    [{"symbol": "HEXP.N0000", "changePercentage": 15.86, ...}]

topLooses

    [{"symbol": "TESS.X0000", "changePercentage": -10.0, ...}]

mostActiveTrades

    [{"symbol": "KZOO.N0000", "tradeVolume": 1102.0, ...}]

getNewListingsRelatedNoticesAnnouncements

    {"newListingRelatedAnnouncements": [{"company": "COMMERCIAL BANK OF CEYLON PLC", ...}]

getBuyInBoardAnnouncements

    {"buyInBoardAnnouncements": [{"company": "TRADING AND MARKET SURVEILLANCE", ...}]

approvedAnnouncement

    {"approvedAnnouncements": [{"company": "LANKEM DEVELOPMENTS PLC", ...}]

getCOVIDAnnouncements

    {"covidAnnouncements": [{"company": "LANKA MILK FOODS (CWE) PLC", ...}]

getFinancialAnnouncement

    {"reqFinancialAnnouncemnets": [{"symbol": "LDEV", "fileText": "Annual Report 2024/2025", ...}]

circularAnnouncement

    {"reqCircularAnnouncement": [{"fileText": "EMPLOYEE SHARE OPTION SCHEMES", ...}]

directiveAnnouncement

    {"reqDirectiveAnnouncement": [{"fileText": "DIRECTIVE ISSUED ...", ...}]

getNonComplianceAnnouncements

    {"nonComplianceAnnouncements": [{"company": "BROWNS BEACH HOTELS PLC", ...}]

marketStatus

    {"status": "Market Closed"}

marketSummery

    {"tradeVolume": 3263762020.0, "shareVolume": 115084307, ...}

aspiData

    {"value": 19826.57, "change": 21.77, ...}

snpData

    {"value": 5825.39, "change": -2.46, ...}

chartData

Requires `symbol` but may return HTTP 400 for some values.

allSectors

    [{"symbol": "EGY", "indexName": "S&P/CSE Energy Industry Group Index", ...}]

Detailed Trades

URL: `https://www.cse.lk/api/detailedTrades`

Parameters: `symbol` (string, not required)

Example Response:

        {
          "reqDetailTrades": [
              {
                  "id": 204,
                  "securityId": null,
                  "name": "ABANS ELECTRICALS PLC",
                  "symbol": "ABAN.N0000",
                  "price": 585.0,
                  "qty": 562,
                  "trades": 7,
                  "change": 29.0,
                  "changePercentage": 5.215827338129497
              },
            ]
          }

Daily Market Summary

URL: `https://www.cse.lk/api/dailyMarketSummery`

Parameters: None

Example Response:

        [
          [
            {
                "id": 22240,
                "tradeDate": 1754505000000,
                "marketTurnover": 3.26376192E9,
                "marketTrades": 30274.0,
                "marketDomestic": 30003.0,
                "marketForeign": 271.0,
                "equityTurnover": 3.26376192E9,
                "equityDomesticPurchase": 3.15549645E9,
                "equityDomesticSales": 3.18251674E9,
                "equityForeignPurchase": 1.08265512E8,
                "equityForeignSales": 8.1245208E7,
                "volumeOfTurnOverNumber": 1.15084304E8,
                "volumeOfTurnoverDomestic": 1.13407144E8,
                "volumeOfTurnoverForeign": 1677157,
                "tradesNo": 30274,
                "tradesNoDomestic": 30003,
                "tradesNoForeign": 271,
                "listedCompanyNumber": 286,
                "tradeCompanyNumber": 264,
                "marketCap": 6.940225783432E12,
                "cdsHoldingsTotal": 1.76301605E11,
                "cdsHoldingsDomestic": 1.45956422E11,
                "cdsHoldingsForeign": 3.03451935E10,
                "cdsMarketValueTotal": 5.5536905E12,
                "cdsMarketValueDomestic": 4.5569682E12,
                "cdsMarketValueForeign": 9.9672234E11,
                "corporateDebtValue": 0.0,
                "governmentDebtValue": 0.0,
                "triasi": 29913.8,
                "spt": 11861.33,
                "asi": 19826.57,
                "mpi": null,
                "spp": 5825.39,
                "trimpi": null,
                "per": 9.2,
                "pbv": 1.3,
                "dy": 2.5
            }
          ],
        ]